aboutsummaryrefslogtreecommitdiff
path: root/contrib/llvm-project/clang/include/clang/Serialization/ASTBitCodes.h
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/llvm-project/clang/include/clang/Serialization/ASTBitCodes.h')
-rw-r--r--contrib/llvm-project/clang/include/clang/Serialization/ASTBitCodes.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/contrib/llvm-project/clang/include/clang/Serialization/ASTBitCodes.h b/contrib/llvm-project/clang/include/clang/Serialization/ASTBitCodes.h
index c6f9f1d1a08f..e9fc202f8d1d 100644
--- a/contrib/llvm-project/clang/include/clang/Serialization/ASTBitCodes.h
+++ b/contrib/llvm-project/clang/include/clang/Serialization/ASTBitCodes.h
@@ -681,8 +681,8 @@ public:
MODULAR_CODEGEN_DECLS = 60,
- /// Record code for \#pragma pack options.
- PACK_PRAGMA_OPTIONS = 61,
+ /// Record code for \#pragma align/pack options.
+ ALIGN_PACK_PRAGMA_OPTIONS = 61,
/// The stack of open #ifs/#ifdefs recorded in a preamble.
PP_CONDITIONAL_STACK = 62,
@@ -1080,6 +1080,9 @@ public:
// \brief SVE types with auto numeration
#define SVE_TYPE(Name, Id, SingletonId) PREDEF_TYPE_##Id##_ID,
#include "clang/Basic/AArch64SVEACLETypes.def"
+ // \brief PowerPC MMA types with auto numeration
+#define PPC_VECTOR_TYPE(Name, Id, Size) PREDEF_TYPE_##Id##_ID,
+#include "clang/Basic/PPCTypes.def"
};
/// The number of predefined type IDs that are reserved for
@@ -1281,6 +1284,9 @@ public:
/// A MSGuidDecl record.
DECL_MS_GUID,
+ /// A TemplateParamObjectDecl record.
+ DECL_TEMPLATE_PARAM_OBJECT,
+
/// A VarDecl record.
DECL_VAR,